#include "Gadget/Engine.h"
#include "iToo.h"

int WINAPI WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{
	Core G;
	G.Window.SetSize(700, 700);
	G.Window.SetClearDepthBuffer(false);
	G.Window.SetFullScreen(false);
	G.Window.Open();
	glDisable(GL_DEPTH_TEST); //Ignore depth

	SoundEngine S; //Only create one instance of the SoundEngine class

	//Load some sounds
	Sound CymbolSnd;
	CymbolSnd.Load("Sounds/cymbol.wav", &S, false, false);

	Sound drumRollSnd;
	drumRollSnd.Load("Sounds/drumroll.wav", &S, false, false);

	Sound snareSnd;
	snareSnd.Load("Sounds/snare.wav", &S, false, false);

	Sound drumSnd;
	drumSnd.Load("Sounds/drum1.wav", &S, false, false);

	//Load the background graphic
	Image backImg;
	backImg.Load("Images/back.jpg");

	Sprite backSpr(float(G.Window.GetWidth()), float(G.Window.GetHeight()));
	backSpr.x = float(G.Window.GetWidth())/2.0f;
	backSpr.y = float(G.Window.GetHeight())/2.0f;

	//Load the target graphic
	Image targetImg;
	targetImg.Load("Images/target.png");

	Sprite targetSpr(128.0f, 128.0f);

	IToo iToo(&G, 0);

	while(G.Window.IsOpen())//loop as long as the window is open
	{
		G.Renderer.BeginFrame(); G.Renderer.Render2D(); //render a 2D scene

			//ESC closes the window
			if(G.Keyboard.GetKeyHold(GLFW_KEY_ESC)) {G.Window.Close();}	

			iToo.Step();

			//Play a sound when the iToo is flicked
			if(iToo.GetFlick())
			{
				//choose the right sound based on which button is pressed
				if(iToo.GetButtonHold(0))
				{
					drumSnd.Play();
				}
				else if(iToo.GetButtonHold(1))
				{
					CymbolSnd.Play();
				}
				else
				{
					snareSnd.Play();
				}
			}

			//The top button plays a drumroll
			if(iToo.GetButtonPress(2))
			{
				drumRollSnd.Play();
			}

			//Render the background
			Shader::Blend(0);
			backImg.Activate();
			backSpr.Render();

			//Draw a red line to show the vertical acceleration
			glColor3f(1.0f, 0.0f, 0.0f);
			Shader::Deactivate();
			DrawLine(Vector2D(80.0f, 350.0f), Vector2D(80.0f, iToo.GetAcceleration()*350.0f+350.0f),10.0f);
			glColor3f(1.0f, 1.0f, 1.0f);

			//Render the target
			Shader::Blend(2);
			targetImg.Activate();
			targetSpr.x = iToo.GetHorizontalTilt()*350.0f+350.0f;
			targetSpr.y = iToo.GetVerticalTilt()*350.0f+350.0f;
			targetSpr.Render();

			S.Update(G.Timer.GetElapsedTime());//The sound engine must be updated constantly

			Shader::Deactivate();//Always a good idea to turn off any shaders when finished rendering
		G.Renderer.EndFrame();//finished rendering
	}
	return 0;
}			