#include "Gadget/Engine.h"
#include "iToo.h"

//Static variables have to be declaired outside of the class as well
Core*  IToo::G;

IToo::IToo(Core* core, int controllerNum)//Constructor
{
	G = core;
	init = false;
	this->controllerNum = controllerNum;

	vTilt = vTiltSmooth = 0.0f;
	hTilt = hTiltSmooth = 0.0f;
	accel = accelSmooth = 0.0f;
	flickSensor = 0.0f;
	flick = flickPrevious = false;

	//make sure this controller is connected
	if(G->Joystick.IsConnected(controllerNum))
	{
		this->controllerNum = controllerNum;
		init = true;
	}
}

void IToo::Step()
{	
	static float smooth;

	if(init)
	{
		//Calculate the tilt
		hTilt = G->Joystick.GetAxis(controllerNum, 0)*2.64f;
		vTilt = G->Joystick.GetAxis(controllerNum, 1)*-2.64f;
		if(hTilt>1.0f)hTilt = 1.0f;
		if(vTilt>1.0f)vTilt = 1.0f;
		if(hTilt<-1.0f)hTilt = -1.0f;
		if(vTilt<-1.0f)vTilt = -1.0f;

		smooth = 0.0167f/G->Timer.GetElapsedTime()*5.0f;

		hTiltSmooth = (hTiltSmooth*smooth+hTilt)/(smooth+1.0f);
		vTiltSmooth = (vTiltSmooth*smooth+vTilt)/(smooth+1.0f);

		//Calculate the vertical acceleration
		float vert = G->Joystick.GetAxis(controllerNum, 2);
		if(vert>-0.415f)
		{
			vert = (vert+0.415f)*0.85f;
		}
		else
		{
			vert = (vert+0.415f)*1.7f;
		}

		float test1, test2;
		test1 = G->Joystick.GetAxis(controllerNum, 0);
		if(test1<0.0f)test1 *= -1.0f;
		test2 = G->Joystick.GetAxis(controllerNum, 1);
		if(test1<0.0f)test1 *= -1.0f;
		if(test2>test1)test1=test2;
			
		vert = vert - test1*0.8f;
			
		accelSmooth = (accelSmooth+(accel-vert))*0.9f;
		if(accelSmooth>1.0f)accelSmooth = 1.0f;
		if(accelSmooth<-1.0f)accelSmooth = -1.0f;

		accel = vert;

		//Calculate the flick motion
		flickSensor = G->Joystick.GetAxis(controllerNum, 3);
		if(flickSensor<-0.5f){flickSensor = 0.6f;}
		flickPrevious = flick;
		flick = flickSensor>0.5f;
	}
}

float IToo::GetVerticalTilt()
{
	return vTiltSmooth;
}

float IToo::GetHorizontalTilt()
{
	return hTiltSmooth;
}

float IToo::GetAcceleration()
{
	return accelSmooth;
}

bool IToo::GetFlick()
{
	return flick && flickPrevious!=flick;
}

bool IToo::GetButtonPress(int buttonNum)
{
	if(buttonNum<0 || buttonNum>2){return false;}
	return G->Joystick.GetButtonPress(controllerNum, buttonNum);
}

bool IToo::GetButtonHold(int buttonNum)
{
	if(buttonNum<0 || buttonNum>2){return false;}
	return G->Joystick.GetButtonHold(controllerNum, buttonNum);
}

bool IToo::GetButtonRelease(int buttonNum)
{
	if(buttonNum<0 || buttonNum>2){return false;}
	return G->Joystick.GetButtonRelease(controllerNum, buttonNum);
}